''' 
Artificial Intelligence Techniques SL	
artelnics@artelnics.com	

Your model has been exported to this python file.
You can manage it with the main method where you 	
can change the values of your inputs. For example:

if we want to add these 3 values (0.3, 2.5 and 1.8)
to our 3 inputs (Input_1, Input_2 and Input_1), the
main program has to look like this:

def main ():
	#default_val = 3.1416
	inputs = [None]*3
	
	Id_1 = 0.3
	Id_1 = 2.5
	Id_1 = 1.8
	
	inputs[0] = Input_1
	inputs[1] = Input_2
	inputs[2] = Input_3
	. . .


Inputs Names: 	
	0) down_hole_presure_lag_1
	1) down_hole_temperature_lag_1
	2) production_pipe_pressure_lag_1
	3) choke_size_pct_lag_1
	4) well_head_presure_lag_1
	5) well_head_temperature_lag_1
	6) choke_size_pressure_lag_1
	7) oil_lag_1
	8) down_hole_presure_lag_0
	9) down_hole_temperature_lag_0
	10) production_pipe_pressure_lag_0
	11) choke_size_pct_lag_0
	12) well_head_presure_lag_0
	13) well_head_temperature_lag_0
	14) choke_size_pressure_lag_0
	15) oil_lag_0


''' 


import math
import numpy as np


class NeuralNetwork:
	def __init__(self):
		self.inputs_number = 16


	def calculate_outputs(self, inputs):
		down_hole_presure_lag_1 = inputs[0]
		down_hole_temperature_lag_1 = inputs[1]
		production_pipe_pressure_lag_1 = inputs[2]
		choke_size_pct_lag_1 = inputs[3]
		well_head_presure_lag_1 = inputs[4]
		well_head_temperature_lag_1 = inputs[5]
		choke_size_pressure_lag_1 = inputs[6]
		oil_lag_1 = inputs[7]
		down_hole_presure_lag_0 = inputs[8]
		down_hole_temperature_lag_0 = inputs[9]
		production_pipe_pressure_lag_0 = inputs[10]
		choke_size_pct_lag_0 = inputs[11]
		well_head_presure_lag_0 = inputs[12]
		well_head_temperature_lag_0 = inputs[13]
		choke_size_pressure_lag_0 = inputs[14]
		oil_lag_0 = inputs[15]

		scaled_down_hole_presure_lag_1 = (down_hole_presure_lag_1-252.3179932)/18.92510033;
		scaled_down_hole_temperature_lag_1 = (down_hole_temperature_lag_1-101.1409988)/4.748660088;
		scaled_production_pipe_pressure_lag_1 = (production_pipe_pressure_lag_1-214.6000061)/26.03879929;
		scaled_choke_size_pct_lag_1 = (choke_size_pct_lag_1-78.42089844)/28.24139977;
		scaled_well_head_presure_lag_1 = (well_head_presure_lag_1-37.50559998)/16.14410019;
		scaled_well_head_temperature_lag_1 = (well_head_temperature_lag_1-83.3812027)/16.26160049;
		scaled_choke_size_pressure_lag_1 = (choke_size_pressure_lag_1-9.438480377)/17.18700027;
		scaled_oil_lag_1 = (oil_lag_1-898.6339722)/731.4899902;
		scaled_down_hole_presure_lag_0 = (down_hole_presure_lag_0-252.2980042)/19.25939941;
		scaled_down_hole_temperature_lag_0 = (down_hole_temperature_lag_0-101.0879974)/4.937150002;
		scaled_production_pipe_pressure_lag_0 = (production_pipe_pressure_lag_0-214.5690002)/26.19440079;
		scaled_choke_size_pct_lag_0 = (choke_size_pct_lag_0-78.34420013)/28.36770058;
		scaled_well_head_presure_lag_0 = (well_head_presure_lag_0-37.54339981)/16.26230049;
		scaled_well_head_temperature_lag_0 = (well_head_temperature_lag_0-83.2582016)/16.48889923;
		scaled_choke_size_pressure_lag_0 = (choke_size_pressure_lag_0-9.507719994)/17.35300064;
		scaled_oil_lag_0 = (oil_lag_0-879.6469727)/695.6140137;
		
		perceptron_layer_1_output_0 = np.tanh( 0.285809 + (scaled_down_hole_presure_lag_1*-0.0345299) + (scaled_down_hole_temperature_lag_1*0.0277876) + (scaled_production_pipe_pressure_lag_1*-0.209406) + (scaled_choke_size_pct_lag_1*-0.0668454) + (scaled_well_head_presure_lag_1*0.369234) + (scaled_well_head_temperature_lag_1*-0.502605) + (scaled_choke_size_pressure_lag_1*-0.456736) + (scaled_oil_lag_1*0.071849) + (scaled_down_hole_presure_lag_0*-0.0361353) + (scaled_down_hole_temperature_lag_0*-0.219351) + (scaled_production_pipe_pressure_lag_0*0.183694) + (scaled_choke_size_pct_lag_0*0.055049) + (scaled_well_head_presure_lag_0*-0.171197) + (scaled_well_head_temperature_lag_0*0.230196) + (scaled_choke_size_pressure_lag_0*0.414232) + (scaled_oil_lag_0*-0.3033) );
		perceptron_layer_1_output_1 = np.tanh( -1.27262 + (scaled_down_hole_presure_lag_1*-0.278392) + (scaled_down_hole_temperature_lag_1*-0.198965) + (scaled_production_pipe_pressure_lag_1*0.198925) + (scaled_choke_size_pct_lag_1*-0.132093) + (scaled_well_head_presure_lag_1*-0.0474358) + (scaled_well_head_temperature_lag_1*-0.291459) + (scaled_choke_size_pressure_lag_1*0.651453) + (scaled_oil_lag_1*-0.0461297) + (scaled_down_hole_presure_lag_0*-0.376054) + (scaled_down_hole_temperature_lag_0*0.157691) + (scaled_production_pipe_pressure_lag_0*0.533761) + (scaled_choke_size_pct_lag_0*0.106495) + (scaled_well_head_presure_lag_0*-0.143798) + (scaled_well_head_temperature_lag_0*0.0973452) + (scaled_choke_size_pressure_lag_0*0.155519) + (scaled_oil_lag_0*0.537454) );
		perceptron_layer_1_output_2 = np.tanh( -0.210355 + (scaled_down_hole_presure_lag_1*-0.285576) + (scaled_down_hole_temperature_lag_1*0.0431009) + (scaled_production_pipe_pressure_lag_1*0.110519) + (scaled_choke_size_pct_lag_1*0.0978518) + (scaled_well_head_presure_lag_1*-0.0600298) + (scaled_well_head_temperature_lag_1*-0.12421) + (scaled_choke_size_pressure_lag_1*0.384057) + (scaled_oil_lag_1*-0.307762) + (scaled_down_hole_presure_lag_0*0.0948291) + (scaled_down_hole_temperature_lag_0*-0.0495558) + (scaled_production_pipe_pressure_lag_0*0.240853) + (scaled_choke_size_pct_lag_0*-0.0242444) + (scaled_well_head_presure_lag_0*-0.619241) + (scaled_well_head_temperature_lag_0*0.250811) + (scaled_choke_size_pressure_lag_0*0.589981) + (scaled_oil_lag_0*-0.158264) );
		
		perceptron_layer_2_output_0 = ( 0.991233 + (perceptron_layer_1_output_0*-1.1729) + (perceptron_layer_1_output_1*1.19837) + (perceptron_layer_1_output_2*-1.17833) );
		
		unscaling_layer_output_0=perceptron_layer_2_output_0*692.8209839+874.5460205;
		
		
		out = [None]*1
		out[0] = oil_ahead_1

		return out;


	def main (self):
		default_val = 3.1416
		inputs = [None]*16

		down_hole_presure_lag_1 = default_val	#Change this value
		inputs[0] = down_hole_presure_lag_1

		down_hole_temperature_lag_1 = default_val	#Change this value
		inputs[1] = down_hole_temperature_lag_1

		production_pipe_pressure_lag_1 = default_val	#Change this value
		inputs[2] = production_pipe_pressure_lag_1

		choke_size_pct_lag_1 = default_val	#Change this value
		inputs[3] = choke_size_pct_lag_1

		well_head_presure_lag_1 = default_val	#Change this value
		inputs[4] = well_head_presure_lag_1

		well_head_temperature_lag_1 = default_val	#Change this value
		inputs[5] = well_head_temperature_lag_1

		choke_size_pressure_lag_1 = default_val	#Change this value
		inputs[6] = choke_size_pressure_lag_1

		oil_lag_1 = default_val	#Change this value
		inputs[7] = oil_lag_1

		down_hole_presure_lag_0 = default_val	#Change this value
		inputs[8] = down_hole_presure_lag_0

		down_hole_temperature_lag_0 = default_val	#Change this value
		inputs[9] = down_hole_temperature_lag_0

		production_pipe_pressure_lag_0 = default_val	#Change this value
		inputs[10] = production_pipe_pressure_lag_0

		choke_size_pct_lag_0 = default_val	#Change this value
		inputs[11] = choke_size_pct_lag_0

		well_head_presure_lag_0 = default_val	#Change this value
		inputs[12] = well_head_presure_lag_0

		well_head_temperature_lag_0 = default_val	#Change this value
		inputs[13] = well_head_temperature_lag_0

		choke_size_pressure_lag_0 = default_val	#Change this value
		inputs[14] = choke_size_pressure_lag_0

		oil_lag_0 = default_val	#Change this value
		inputs[15] = oil_lag_0


		outputs = NeuralNetwork.calculate_outputs(self, inputs)

		print("\nThese are your outputs:\n")
		print( "\t oil_ahead_1:" + str(outputs[0]) + "\n" )

nn = NeuralNetwork()
nn.main()
